Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(324)

Unified Diff: media/filters/chunk_demuxer_unittest.cc

Issue 1312763014: Rename WebSourceBuffer::abort -> resetParserState (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/filters/chunk_demuxer.cc ('k') | media/test/pipeline_integration_test.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/filters/chunk_demuxer_unittest.cc
diff --git a/media/filters/chunk_demuxer_unittest.cc b/media/filters/chunk_demuxer_unittest.cc
index a01a50b18b9e70d58edf91ad592f11342323360d..99299ac305dd0f346d3862b44188b8740a6cbb26 100644
--- a/media/filters/chunk_demuxer_unittest.cc
+++ b/media/filters/chunk_demuxer_unittest.cc
@@ -3029,13 +3029,13 @@ TEST_F(ChunkDemuxerTest, IsParsingMediaSegmentMidMediaSegment) {
// Confirm we're in the middle of parsing a media segment.
ASSERT_TRUE(demuxer_->IsParsingMediaSegment(kSourceId));
- demuxer_->Abort(kSourceId,
- append_window_start_for_next_append_,
- append_window_end_for_next_append_,
- &timestamp_offset_map_[kSourceId]);
+ demuxer_->ResetParserState(kSourceId,
+ append_window_start_for_next_append_,
+ append_window_end_for_next_append_,
+ &timestamp_offset_map_[kSourceId]);
- // After Abort(), parsing should no longer be in the middle of a media
- // segment.
+ // After ResetParserState(), parsing should no longer be in the middle of a
+ // media segment.
ASSERT_FALSE(demuxer_->IsParsingMediaSegment(kSourceId));
}
@@ -3068,14 +3068,14 @@ TEST_F(ChunkDemuxerTest, EmitBuffersDuringAbort) {
// Confirm we're in the middle of parsing a media segment.
ASSERT_TRUE(demuxer_->IsParsingMediaSegment(kSourceId));
// Abort on the Mpeg2 TS parser triggers the emission of the last video
// buffer which is pending in the stream parser.
Ranges<base::TimeDelta> range_before_abort =
demuxer_->GetBufferedRanges(kSourceId);
- demuxer_->Abort(kSourceId,
- append_window_start_for_next_append_,
- append_window_end_for_next_append_,
- &timestamp_offset_map_[kSourceId]);
+ demuxer_->ResetParserState(kSourceId,
+ append_window_start_for_next_append_,
+ append_window_end_for_next_append_,
+ &timestamp_offset_map_[kSourceId]);
Ranges<base::TimeDelta> range_after_abort =
demuxer_->GetBufferedRanges(kSourceId);
@@ -3116,12 +3116,12 @@ TEST_F(ChunkDemuxerTest, SeekCompleteDuringAbort) {
// abort.
Seek(base::TimeDelta::FromMilliseconds(4110));
- // Abort on the Mpeg2 TS parser triggers the emission of the last video
- // buffer which is pending in the stream parser.
- demuxer_->Abort(kSourceId,
- append_window_start_for_next_append_,
- append_window_end_for_next_append_,
- &timestamp_offset_map_[kSourceId]);
+ // ResetParserState on the Mpeg2 TS parser triggers the emission of the last
+ // video buffer which is pending in the stream parser.
+ demuxer_->ResetParserState(kSourceId,
+ append_window_start_for_next_append_,
+ append_window_end_for_next_append_,
+ &timestamp_offset_map_[kSourceId]);
}
#endif
« no previous file with comments | « media/filters/chunk_demuxer.cc ('k') | media/test/pipeline_integration_test.cc » ('j') | no next file with comments »
@@ -3068,14 +3068,14 @@ TEST_F(ChunkDemuxerTest, EmitBuffersDuringAbort) {
// Confirm we're in the middle of parsing a media segment.
ASSERT_TRUE(demuxer_->IsParsingMediaSegment(kSourceId));
- // Abort on the Mpeg2 TS parser triggers the emission of the last video
- // buffer which is pending in the stream parser.
+ // ResetParserState on the Mpeg2 TS parser triggers the emission of the last
+ // video buffer which is pending in the stream parser.
Ranges<base::TimeDelta> range_before_abort =
demuxer_->GetBufferedRanges(kSourceId);

Powered by Google App Engine
This is Rietveld 408576698